function Connectivity_Matrix_View(NChannels,Method,EEGFrequency,EEGData,Analyzer,FileName)          % jrn/28.02.2017

%% Connectivity_Matrix - Create a 2D View of Connectivity values
% ==============================================================
%
% NChannels: Nunmber of channels from which all channel pairs are created.
% Method: One of the five options in the Method groupbox of the Coherence transform:
% Coherence: 'COH'
% Cross-spectrum: 'SPECT'
% Phase: 'PHASE'
% Imaginary Coherency: 'ICOH' 
% Correlation Coefficient: 'CORRC'
%
% This function can be used only for Coherence data 
% while the option "All Channel Pairs" is used.
%
% =============================================
% Author: Jose R Naranjo   
% Scientific Consultant
% Software and Scientific Support Department
% Brain Products GmbH
% =============================================
%
% this MATLAB script is intended to work only for this application

%% Check NChannels

if ~(isnumeric(NChannels) && (mod(NChannels,1) == 0) && (NChannels > 1))
    disp('Connectivity_Matrix_View(NChannels,Method,EEGFrequency,EEGData)')
    error('NChannels shall be an integer larger than 1');
elseif (NChannels*NChannels - NChannels)/2  ~= size(EEGData,2)
    disp('Connectivity_Matrix_View(NChannels,Method,EEGFrequency,EEGData)')
    error(['NChannels(',num2str(NChannels),') do not match the number of channel pairs(',num2str(size(EEGData,2)),')']);
end

%% Check method and set connectivity matrix

switch Method
    case {'COH','CORRC'}
        ConnMatrix=ones(NChannels);
    case 'SPECT'
        ConnMatrix=NaN(NChannels);
%       REMARK: Power Spectrum for each channel (diagonal) is unknown
    case {'PHASE', 'ICOH'}
        ConnMatrix=zeros(NChannels);
    otherwise
        disp('Connectivity_Matrix(NChannels,Method,EEGFrequency,EEGData)')
        error('Method shall be {COH, SPECT, PHASE, ICOH, CORRC}');
end


%% Define Frequency Bands here!

Freqband(1).name='Delta';   Freqband(1).range=[0.5 3.5];
Freqband(2).name='Theta';   Freqband(2).range=[3.5 7.5];
Freqband(3).name='Alpha';   Freqband(3).range=[7.5 12.5];
Freqband(4).name='Beta';    Freqband(4).range=[12.5 30];

% NOTES:
% 1- The four frequency bands are defined as the Analyzer default bands,
% but can be modified or extended.
% 2- Each band is displayed in a subplot pane. 

%% Connectivity VIEW
figure('position', [400, 300, 800, 600])
annotation('textbox', [0 0.9 1 0.1],'String',['Connectivity Matrix - ', Method],'EdgeColor','none','HorizontalAlignment','center','fontweight','bold','fontsize',12);

% for each band
NBands=length(Freqband);

for i=1:NBands
    
    fmin=find(EEGFrequency<=min(Freqband(i).range), 1, 'last' );
    fmax=max(find(EEGFrequency<=max(Freqband(i).range))-1);
    
    meanCOH=mean(EEGData(fmin:fmax,1:end),1);  % compute mean Coherence in band
    
    k=0; %counter 
    for m=1:NChannels
        for n=m+1:NChannels  % Diagonal data is unknown/not exported to MATLAB
            k=k+1;
            ConnMatrix(m,n)=meanCOH(k);                 %upper triangle
            switch Method
                case {'COH','CORRC','SPECT'}
                    ConnMatrix(n,m)=ConnMatrix(m,n);    % lower triangle
                case {'PHASE', 'ICOH'}
                    ConnMatrix(n,m)=-ConnMatrix(m,n);   % lower triangle
            end
        end;
    end;
    
    % compute max and min Values
    maxV=ceil(max(max(ConnMatrix)));
    switch Method
        case {'COH','CORRC','SPECT'}
            minV=0;
        case {'PHASE', 'ICOH'}
            minV=-maxV;
    end
    
    % display connectivity matrix
    
    subplot(2,2,i);
    
    imagesc(ConnMatrix,[minV maxV]); title(Freqband(i).name);colorbar;
    set(gca, 'YTick', [1 round(NChannels/4) round(NChannels/2) round(3*NChannels/4) NChannels]); 
    set(gca, 'XTick', [1 round(NChannels/4) round(NChannels/2) round(3*NChannels/4) NChannels]);
    axis square;
    
end

%% Save and open Connectivity Matrix Figure in Analyzer Export Folder 

fig_name=[Analyzer.ExportFileFolder,'\',FileName,'_ConnMatrix_',Method,'.tif'];

saveas(gcf,fig_name);
winopen(fig_name);

end